/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.uinfo.salix;

import java.io.Serializable;
import java.text.NumberFormat;

import org.apache.commons.lang.StringUtils;

/**
 * @author Domenico Nardi Tironi
 *
 */
public class SalixScenario implements Serializable {

    private static final long serialVersionUID = 1L;

    private final double salix_value;
    private final int deltaW;
    private final double salixW;

    public SalixScenario(final int deltaW, final double salix_value, final double salixW) {
        this.deltaW = deltaW;
        this.salix_value = salix_value;
        this.salixW = salixW;
    }

    public double getSalixValue() {
        return this.salix_value;
    }

    public int getDeltaW() {
        return this.deltaW;
    }

    public String getDeltaWFormatted() {
        // if (Double.isNaN(this.deltaW))
        // return StringUtils.EMPTY;

        return String.valueOf(this.deltaW);
    }

    public String getSalixValueFormatted(final NumberFormat formatter) {
        if (Double.isNaN(this.salix_value))
            return StringUtils.EMPTY;

        return formatter.format(this.salix_value);
    }

    public double getSalixW() {
        return this.salixW;
    }

    public String getSalixWFormatted(final NumberFormat formatter) {
        if (Double.isNaN(this.salixW))
            return StringUtils.EMPTY;

        return formatter.format(this.salixW);
    }

    public static final String getScenarioValueHeader() {
        return "uinfo.export.salix_line.csv.header.scenario";
    }

    public static final String getDeltaWHeader() {
        return "uinfo.export.salix_line.csv.header.scenario_deltaw";
    }
}